@@ -1,5 +1,4 @@
 import inspect
-import logging
 import traceback
 from pathlib import Path
 
@@ -174,12 +173,12 @@ class DiscordHelper:
                     self.url, json=payload, proxy=self.proxy
                 ) as response:
                     if response.status != 204:
-                        logging.warning(
+                        print(
                             f"Ошибка отправки в Discord: {response.status} - {await response.text()}"
                         )
         except Exception as e:
-            logging.error(traceback.format_exc())
-            logging.error(f"Ошибка при отправке сообщения в Discord: {e}")
+            print(traceback.format_exc())
+            print(f"Ошибка при отправке сообщения в Discord: {e}")
 
         self.reset()
 
